@@ -7,7 +7,9 @@ from baseball.fetch_game import (get_game_from_url,
                                  get_game_list_from_file_range,
                                  get_game_from_xml_strings,
                                  get_game_from_files,
-                                 get_filename_list)
+                                 get_filename_list,
+                                 generate_today_game_svgs,
+                                 write_games_for_date)
 
 from baseball.process_game_xml import MLB_TEAM_CODE_DICT
 
