@@ -5,6 +5,7 @@ from re import search, sub, findall, escape
 from json import dumps
 from pytz import timezone
 
+from baseball.baseball_events import RunnerAdvance
 from baseball.generate_svg import get_game_svg_str
 from baseball.stats import (get_all_pitcher_stats,
                             get_all_batter_stats,
@@ -52,7 +53,7 @@ PLAY_CODE_ORDERED_DICT = OrderedDict([
     ('sacrifice fly', 'SF'),
     ('hit by pitch', 'HBP'),
     ('bunt', 'B'),
-    ('sacrifice bunt', 'SB'),
+    ('sacrifice bunt', 'SH'),
     ('walks', 'BB'),
     ('intentionally walks', 'IBB'),
     ('called out on strikes', 'ꓘ'),
@@ -62,6 +63,10 @@ PLAY_CODE_ORDERED_DICT = OrderedDict([
 
 NO_HIT_CODE_LIST = ['K', 'ꓘ', 'BB', 'IBB']
 
+BASE_PLUS_ONE_DICT = {'1B': '2nd',
+                      '2B': '3rd',
+                      '3B': 'home'}
+
 INCREMENT_BASE_DICT = {'1st': '2nd',
                        '2nd': '3rd',
                        '3rd': 'home'}
@@ -79,7 +84,7 @@ STADIUM_TIMEZONE_DICT = {
     'The Ballpark of the Palm Beaches': 'America/New_York',
     'Citizens Bank Park': 'America/New_York',
     'Spectrum Field': 'America/New_York',
-    'Oriole Park at Camden Yards': 'America/New_York',
+    'Oriole Park': 'America/New_York',
     'Nationals Park': 'America/New_York',
     'Champion Stadium': 'America/New_York',
     'Truist Park': 'America/New_York',
@@ -98,15 +103,17 @@ STADIUM_TIMEZONE_DICT = {
     'Globe Life Field': 'America/Chicago',
     'Minute Maid Park': 'America/Chicago',
     'Kauffman Stadium': 'America/Chicago',
+    'American Family Field': 'America/Chicago',
     'Coors Field': 'America/Denver',
     'Chase Field': 'America/Denver',
     'Safeco Field': 'America/Los_Angeles',
     'AT&T Park': 'America/Los_Angeles',
     'Oakland-Alameda County Coliseum': 'America/Los_Angeles',
     'Oakland Coliseum': 'America/Los_Angeles',
-    'Angel Stadium of Anaheim': 'America/Los_Angeles',
+    'Angel Stadium': 'America/Los_Angeles',
     'Dodger Stadium': 'America/Los_Angeles',
-    'Petco Park': 'America/Los_Angeles'
+    'Petco Park': 'America/Los_Angeles',
+    'T-Mobile Park': 'America/Los_Angeles'
 }
 
 
@@ -133,11 +140,11 @@ def strip_suffixes(input_str):
     input_str = sub(r' IV', '', input_str)
     input_str = sub(r' St\. ', ' St ', input_str)
 
-    initials_match = findall(r'([A-Z]\.[A-Z]\.?)', input_str)
+    initials_match = findall(r'([A-Z]\.[A-Z]\.? )', input_str)
     while initials_match:
         new_initials = initials_match[0].replace('.', '')
         input_str = sub(initials_match[0], new_initials, input_str, 1)
-        initials_match = findall(r'([A-Z]\.[A-Z]\.?)', input_str)
+        initials_match = findall(r'([A-Z]\.[A-Z]\.? )', input_str)
 
     return input_str
 
@@ -213,6 +220,8 @@ class Player(object):
         self.number = number
 
         self.era = None
+        self.pitch_hand = None
+        self.bat_side = None
 
     def _asdict(self):
         return (
@@ -222,7 +231,9 @@ class Player(object):
              'obp': self.obp,
              'slg': self.slg,
              'number': self.number,
-             'era': self.era}
+             'era': self.era,
+             'pitch_hand': self.pitch_hand,
+             'bat_side': self.bat_side}
         )
 
     def full_name(self):
@@ -238,7 +249,13 @@ class Player(object):
         return return_str
 
     def pitching_stats(self):
-        return 'ERA: {}'.format('%.2f' % self.era)
+        if self.era:
+            era_str = 'ERA: {}'.format('%.2f' % self.era)
+        else:
+            era_str = 'ERA: {}'.format(self.era)
+
+        return era_str
+
 
     def __repr__(self):
         return_str = ''
@@ -384,6 +401,10 @@ class Game(object):
         self.start_str = ''
         self.end_str = ''
 
+        self.attendance = None
+        self.temp = None
+        self.weather = None
+
     def json(self):
         return dumps(self._asdict())
 
@@ -629,7 +650,9 @@ class PlateAppearance(object):
         self.runners_batted_in_list = runners_batted_in_list
         self.out_runners_list = self.get_out_runners_list(
             self.plate_appearance_description,
-            self.batting_team
+            self.batting_team,
+            self.event_list,
+            self.batter
         )
 
         self.hit_location = self.get_hit_location()
@@ -751,7 +774,8 @@ class PlateAppearance(object):
         return defense_suffix
 
     @staticmethod
-    def get_out_runners_list(plate_appearance_description, batting_team):
+    def get_out_runners_list(plate_appearance_description, batting_team,
+                             event_list, batter):
         description = strip_suffixes(plate_appearance_description)
         runner_name_list = findall(
             (r'([A-Z][\w\'-]+\s+(?:[A-Z,a-z][\w\'-]+\s+)?'
@@ -763,6 +787,24 @@ class PlateAppearance(object):
             description
         )
 
+        runner_in_list = False
+        for event in event_list:
+            if (isinstance(event, RunnerAdvance) and event.end_base == ''
+                    and not event.runner_scored and event.runner != batter):
+                for name, _ in runner_name_list:
+                    if event.runner.last_name in name:
+                        runner_in_list = True
+                        break
+
+                if not runner_in_list:
+                    runner_name_list.append(
+                        (
+                            '{} {}'.format(event.runner.first_name,
+                                           event.runner.last_name),
+                            BASE_PLUS_ONE_DICT[event.start_base]
+                        )
+                    )
+
         runner_tuple_list = []
         for name, base in runner_name_list:
             search_pattern = escape(name) + r' (?:was )?doubled off'
