@@ -12,6 +12,40 @@ FakePlateAppearance = namedtuple(
     'scorecard_summary batter plate_appearance_description'
 )
 
+LOGO_DICT = {
+    'LAA': 'team_logos/angels.gif',
+    'HOU': 'team_logos/astros.gif',
+    'OAK': 'team_logos/athletics.gif',
+    'TOR': 'team_logos/blue-jays.gif',
+    'ATL': 'team_logos/braves.gif',
+    'MIL': 'team_logos/brewers.gif',
+    'STL': 'team_logos/cardinals.gif',
+    'CHC': 'team_logos/cubs.gif',
+    'ARI': 'team_logos/diamondbacks.gif',
+    'LAD': 'team_logos/dodgers.gif',
+    'SF': 'team_logos/giants.gif',
+    'CLE': 'team_logos/indians.gif',
+    'SEA': 'team_logos/mariners.gif',
+    'MIA': 'team_logos/marlins.gif',
+    'NYM': 'team_logos/mets.gif',
+    'WSH': 'team_logos/nationals.gif',
+    'BAL': 'team_logos/orioles.gif',
+    'SD': 'team_logos/padres.gif',
+    'PHI': 'team_logos/phillies.gif',
+    'PIT': 'team_logos/pirates.gif',
+    'TEX': 'team_logos/rangers.gif',
+    'TB': 'team_logos/rays.gif',
+    'CIN': 'team_logos/reds.gif',
+    'BOS': 'team_logos/red-sox.gif',
+    'COL': 'team_logos/rockies.gif',
+    'KC': 'team_logos/royals.gif',
+    'DET': 'team_logos/tigers.gif',
+    'MIN': 'team_logos/twins.gif',
+    'CWS': 'team_logos/white-sox.gif',
+    'CHW': 'team_logos/white-sox.gif',
+    'NYY': 'team_logos/yankees.gif'
+}
+
 
 HEIGHT = 4513
 WIDTH = 3192
@@ -31,15 +65,20 @@ PITCH_SPEED_X_OFFSET = 39
 FIRST_PITCH_X_VAL = 3
 FIRST_PITCH_Y_VAL = 15
 PITCHER_LARGE_FONT_SIZE = 20
+PITCHER_MED_FONT_SIZE = 17
 PITCHER_SMALL_FONT_SIZE = 13
 PITCHER_STATS_LARGE_FONT_SIZE = 15
+PITCHER_STATS_MED_FONT_SIZE = 13
 PITCHER_STATS_SMALL_FONT_SIZE = 10
 PITCHER_BOX_SCORE_LARGE_Y = 70
+PITCHER_BOX_SCORE_MED_Y = 64
 PITCHER_BOX_SCORE_SMALL_Y = 56
 PITCHER_BOX_SCORE_X_INCREMENT = 70
 PITCHER_BOX_SCORE_LARGE_Y_INCREMENT = 40
+PITCHER_BOX_SCORE_MED_Y_INCREMENT = 34
 PITCHER_BOX_SCORE_SMALL_Y_INCREMENT = 26
 PITCHER_BOX_STATS_LARGE_Y_OFFSET = 73
+PITCHER_BOX_STATS_MED_Y_OFFSET = 70
 PITCHER_BOX_STATS_SMALL_Y_OFFSET = 67
 SMALL_CHUNK_SIZE = 5
 LARGE_CHUNK_SIZE = 8
@@ -67,15 +106,19 @@ LEFT_FIELDER_X = 105
 CENTER_FIELDER_Y = 35
 RIGHT_FIELDER_X = 225
 BATTER_FONT_SIZE_BIG = 20
+BATTER_FONT_SIZE_MED_PLUS = 18
 BATTER_FONT_SIZE_MED = 15
 BATTER_FONT_SIZE_SMALL = 10
 BATTER_SPACE_BIG = 38
+BATTER_SPACE_MED_PLUS = 32
 BATTER_SPACE_MED = 22
 BATTER_SPACE_SMALL = 15
 BATTER_STATS_OFFSET_BIG = 15
+BATTER_STATS_OFFSET_MED_PLUS = 13
 BATTER_STATS_OFFSET_MED = 10
 BATTER_STATS_OFFSET_SMALL = 6
 BATTER_STATS_SPACES_BIG = 4
+BATTER_STATS_SPACES_MED_PLUS = 5
 BATTER_STATS_SPACES_MED = 6
 BATTER_STATS_SPACES_SMALL = 10
 BATTER_INITIAL_Y_POS = 25
@@ -333,16 +376,19 @@ BIG_SVG_TITLE = (
     'stroke="black" stroke-width="1"/>'
     '<text x="133" y="67" font-family="Arial" text-anchor="middle" '
     'font-size="50">{inning_half}</text>'
-    '<text x="95" y="700" transform="rotate(-90,95,700)" '
+    '<text x="80" y="700" transform="rotate(-90,80,700)" '
     'fill="black" font-size="55" font-family="Arial" text-anchor="middle" '
     '>{game_str}</text>'
-    '<text x="165" y="700" transform="rotate(-90,165,700)" '
+    '<text x="145" y="700" transform="rotate(-90,145,700)" '
     'fill="black" font-size="45" font-family="Arial" text-anchor="middle" '
     '>{location}</text>'
-    '<text x="220" y="700" transform="rotate(-90,220,700)" '
+    '<text x="200" y="700" transform="rotate(-90,200,700)" '
     'fill="black" font-size="30" font-family="Arial" text-anchor="middle" '
     '>{datetime}</text>'
-    '</svg>'
+    '<text x="235" y="700" transform="rotate(-90,235,700)" '
+    'fill="black" font-size="30" font-family="Arial" text-anchor="middle" '
+    '>{detail_str}</text>'
+    '</svg>' 
 )
 
 BOX_SCORE_COLUMN_HEADER = (
@@ -393,17 +439,25 @@ BATTER_NAME_TEMPLATE = (
     'text-anchor="end">{appears}</text>'
 )
 
-SIGNATURE = (
+HOME_LOGO = (
     '<svg x="{x_pos}" y="{y_pos}" width="266" height="200" version="1.1" '
     'xmlns="http://www.w3.org/2000/svg" '
     'xmlns:xlink="http://www.w3.org/1999/xlink">'
     '<rect x="0" y="0" width="266" height="200" stroke="black" fill="white" '
     'stroke-width="1"/>'
-    '<a target="_parent" xlink:href="http://www.livebaseballscorecards.com">'
-    '<image xlink:href="baseball-fairy-161.png" x="50" y="10" height="161" '
+    '<image xlink:href="{logo}" x="50" y="0" height="200" '
+    'width="163" />'
+    '</svg>'
+)
+
+AWAY_LOGO = (
+    '<svg x="{x_pos}" y="{y_pos}" width="266" height="200" version="1.1" '
+    'xmlns="http://www.w3.org/2000/svg" '
+    'xmlns:xlink="http://www.w3.org/1999/xlink">'
+    '<rect x="0" y="0" width="266" height="200" stroke="black" fill="white" '
+    'stroke-width="1"/>'
+    '<image xlink:href="{logo}" x="50" y="0" height="200" '
     'width="163" />'
-    '<text x="133" y="190" font-family="Arial" font-size="20" '
-    'text-anchor="middle" fill="blue">livebaseballscorecards.com</text></a>'
     '</svg>'
 )
 
@@ -447,6 +501,12 @@ BIG_RECTANGLE = ('<path d="M0 {y_pos} L {width} {y_pos} '
 FOOTER_BOX = (
     '<rect x="0" y="0" width="{width}" height="4513" fill="none" '
     'stroke="black" stroke-width="4"/>'
+    '<a target="_parent" xlink:href="http://www.livebaseballscorecards.com">'
+    '<text x="{text_pos}" y="3545" font-family="Arial" font-size="20" '
+    'text-anchor="right" fill="blue">livebaseballscorecards.com</text></a>'
+    '<a target="_parent" xlink:href="http://www.livebaseballscorecards.com">'
+    '<text x="{text_pos}" y="1290" font-family="Arial" font-size="20" '
+    'text-anchor="right" fill="blue">livebaseballscorecards.com</text></a>'
 )
 
 SVG_PITCH_TEMPLATE = (
@@ -867,13 +927,20 @@ def get_runner_end_base_str(plate_appearance, event):
 
     return this_end_base_str
 
+def get_player_last_name(player_obj):
+    return player_obj.last_name
+
 def get_runners_svg(plate_appearance):
     runner_svg_str = ''
     all_runners_list = list(
         set([event.runner for event in plate_appearance.event_list
-             if isinstance(event, RunnerAdvance)])
+             if (isinstance(event, RunnerAdvance) and
+                 event.runner != plate_appearance.batter)])
     )
 
+    all_runners_list.sort(key=get_player_last_name)
+
+    y_val_list = []
     for runner in all_runners_list:
         start_base_num = 1000
         color = None
@@ -902,17 +969,25 @@ def get_runners_svg(plate_appearance):
         if color:
             summary = '{}-{}'.format(start_base_num, this_end_base)
             is_forceout_desc = ('Forceout' in runner_event.run_description or
-                                'Double Play' in runner_event.run_description or
-                                'Triple Play' in runner_event.run_description or
-                                'DP' in runner_event.run_description or
-                                'TP' in runner_event.run_description)
+                                ('Double Play' in runner_event.run_description and
+                                 'F' not in plate_appearance.scorecard_summary and
+                                 'L' not in plate_appearance.scorecard_summary) or
+                                ('Triple Play' in runner_event.run_description and
+                                 'F' not in plate_appearance.scorecard_summary and
+                                 'L' not in plate_appearance.scorecard_summary) or
+                                ('DP' in runner_event.run_description and
+                                 'F' not in plate_appearance.scorecard_summary and
+                                 'L' not in plate_appearance.scorecard_summary) or
+                                ('TP' in runner_event.run_description and
+                                 'F' not in plate_appearance.scorecard_summary and
+                                 'L' not in plate_appearance.scorecard_summary))
 
             if (is_forceout_desc and runner_event.end_base == '' and this_end_base and
                     not runner_event.runner_scored):
                 summary += 'f'
 
             title_flag_str = get_runner_title_str(runner_event)
- 
+
             title = '{}: {}{}'.format(
                 str(runner_event.runner),
                 runner_event.run_description,
@@ -925,6 +1000,10 @@ def get_runners_svg(plate_appearance):
             elif start_base_num == 3:
                 y_val += (RUNNER_SUMMARY_Y_OFFSET * 2)
 
+            while y_val in y_val_list:
+                y_val -= RUNNER_SUMMARY_Y_OFFSET
+
+            y_val_list.append(y_val)
             runner_svg_str += SVG_RUNNER_TEMPLATE.format(
                 y_val=y_val,
                 color=color,
@@ -1114,6 +1193,12 @@ def fix_pa(plate_appearance, event):
         description = '{} batting: Defensive Indifference'.format(
             plate_appearance.batter
         )
+    elif 'Pickoff Error' in event.run_description:
+        summary = 'E'
+        description = '{} batting: {}'.format(
+            plate_appearance.batter,
+            event.run_description
+        )
 
     if summary and description:
         return_pa = FakePlateAppearance(summary,
@@ -1128,7 +1213,7 @@ def get_base_svg(plate_appearance, plate_appearance_list):
     plate_appearance_index = plate_appearance_list.index(plate_appearance)
     plate_appearance_list = plate_appearance_list[plate_appearance_index:plate_appearance_index+8]
 
-    second_base_pa, third_base_pa, home_plate_pa = None, None, None
+    first_base_pa, second_base_pa, third_base_pa, home_plate_pa = None, None, None, None
     batter_final_base, batter_out_base, batter_is_done = None, None, None
 
     batter = plate_appearance.batter
@@ -1140,9 +1225,18 @@ def get_base_svg(plate_appearance, plate_appearance_list):
                     batter_is_done = True
 
                 for out_runner, out_base in this_pa.out_runners_list:
+                    if out_base == '1st' and event.start_base == '1B':
+                        out_base = '2nd'
+                    if out_base == '2nd' and event.start_base == '2B':
+                        out_base = '3rd'
+                    if out_base == '3rd' and event.start_base == '3B':
+                        out_base = 'home'
+
                     if out_runner == batter:
                         if out_base == '1st':
                             batter_out_base = '1B'
+                            if plate_appearance != this_pa:
+                                first_base_pa = fix_pa(this_pa, event)
                         elif out_base == '2nd':
                             batter_out_base = '2B'
                             if plate_appearance != this_pa:
@@ -1338,6 +1432,16 @@ def get_batter_spacing_values(batter_list):
             ('&#160;' * BATTER_STATS_SPACES_SMALL + '%s') * 6
         )
 
+    for batter in batter_list:
+        if len(str(batter.player_obj)) > 18 and batter_font_size == BATTER_FONT_SIZE_BIG:
+            batter_font_size = BATTER_FONT_SIZE_MED_PLUS
+            batter_space_increment = BATTER_SPACE_MED_PLUS
+            stats_y_offset = BATTER_STATS_OFFSET_MED_PLUS
+            box_score_line_template = (
+                ('&#160;' * (BATTER_STATS_SPACES_MED_PLUS // 2)) + '%s' +
+                ('&#160;' * BATTER_STATS_SPACES_MED_PLUS + '%s') * 6
+            )
+
     return (batter_font_size,
             batter_space_increment,
             stats_y_offset,
@@ -1403,6 +1507,11 @@ def get_team_batter_list(team, offset):
                 stats_str = ''
             else:
                 batter_str = '{}'.format(batter_appearance.player_obj)
+                if batter_appearance.player_obj.bat_side:
+                    batter_str += ', {}'.format(
+                        batter_appearance.player_obj.bat_side
+                    )
+
                 if (batter_appearance.player_obj.obp and
                         batter_appearance.player_obj.slg):
                     stats_str = 'OBP: {:.3f}, SLG: {:.3f}'.format(
@@ -1750,6 +1859,14 @@ def get_pitcher_box_score_lines(pitcher_app_list, chunk_size, box_score_dict):
         stats_offset = PITCHER_BOX_STATS_SMALL_Y_OFFSET
         defined_text_increment = PITCHER_BOX_SCORE_SMALL_Y_INCREMENT
 
+    for pitcher_app in pitcher_app_list:
+        if len(str(pitcher_app.player_obj)) > 18 and chunk_size == SMALL_CHUNK_SIZE:
+            initial_y = PITCHER_BOX_SCORE_MED_Y
+            text_size_1 = PITCHER_MED_FONT_SIZE
+            text_size_2 = PITCHER_STATS_MED_FONT_SIZE
+            stats_offset = PITCHER_BOX_STATS_MED_Y_OFFSET
+            defined_text_increment = PITCHER_BOX_SCORE_MED_Y_INCREMENT
+
     for pitcher_app in pitcher_app_list:
         initial_y = PITCHER_BOX_SCORE_SMALL_Y
         box_score_tuple = box_score_dict[pitcher_app.player_obj]
@@ -1758,11 +1875,15 @@ def get_pitcher_box_score_lines(pitcher_app_list, chunk_size, box_score_dict):
         appears_str = '({}, {})'.format(pitcher_app.start_inning_num,
                                         pitcher_app.position)
 
+        pitcher_str = '{}'.format(pitcher_app.player_obj)
+        if pitcher_app.player_obj.pitch_hand:
+            pitcher_str += ', {}'.format(pitcher_app.player_obj.pitch_hand)
+
         pitcher_rows_svg += PITCHER_STATS_LINE_TEMPLATE.format(
             pitcher_id=pitcher_app.player_obj.mlb_id,
             name_y_pos=initial_y + row_increment,
             stats_y_pos=stats_offset + row_increment,
-            pitcher=pitcher_app.player_obj,
+            pitcher=pitcher_str,
             box_score_1=box_score_tuple.IP, box_score_2=box_score_tuple.WLS,
             box_score_3=box_score_tuple.BF, box_score_4=box_score_tuple.H,
             box_score_5=box_score_tuple.R, box_score_6=box_score_tuple.ER,
@@ -1935,24 +2056,24 @@ def assemble_stats_svg(game):
 
     return stats_svg
 
-def get_signature(game):
+def get_logo(game):
     signature_svg = ''
     game_width = get_game_width(game)
 
-    tuple_list = [
-        (
-            game_width - BOX_WIDTH,
-            8 * BOX_HEIGHT + BOX_HEIGHT // 2
-        ),
-        (
-            game_width - BOX_WIDTH,
-            (8 * BOX_HEIGHT + BOX_HEIGHT // 2 +
-             HEIGHT // 2)
-        )
-    ]
+    signature_svg = ''
+    x_pos = game_width - BOX_WIDTH
+    y_pos = 8 * BOX_HEIGHT + BOX_HEIGHT // 2
+    away_logo_str = LOGO_DICT[game.away_team.abbreviation]
+    signature_svg += AWAY_LOGO.format(x_pos=x_pos,
+                                      y_pos=y_pos,
+                                      logo=away_logo_str)
 
-    for x_pos, y_pos in tuple_list:
-        signature_svg += SIGNATURE.format(x_pos=x_pos, y_pos=y_pos)
+    x_pos = game_width - BOX_WIDTH
+    y_pos = 8 * BOX_HEIGHT + BOX_HEIGHT // 2 + HEIGHT // 2
+    home_logo_str = LOGO_DICT[game.home_team.abbreviation]
+    signature_svg += HOME_LOGO.format(x_pos=x_pos,
+                                      y_pos=y_pos,
+                                      logo=home_logo_str)
 
     return signature_svg
 
@@ -2036,6 +2157,22 @@ def assemble_game_title_svg(game):
         game_datetime = game.game_date_str
 
     game_width = get_game_width(game)
+    location_str = game.location.replace('&', '&amp;')
+    detail_str = ''
+    if game.attendance:
+        detail_str += 'Att. {:,}'.format(int(game.attendance))
+
+    if game.weather:
+        if detail_str != '':
+            detail_str += ' - '
+
+        detail_str += game.weather
+
+    if game.temp:
+        if detail_str != '':
+            detail_str += ' - '
+
+        detail_str += '{} F'.format(int(game.temp))
 
     tuple_list = [('TOP', 0), ('BOTTOM', HEIGHT // 2)]
     for inning_half_str, y_pos in tuple_list:
@@ -2044,8 +2181,9 @@ def assemble_game_title_svg(game):
             y_pos=y_pos,
             inning_half=inning_half_str,
             game_str=game_str,
-            location=game.location.replace('&', '&amp;'),
-            datetime=game_datetime
+            location=location_str,
+            datetime=game_datetime,
+            detail_str=detail_str
         )
 
     return game_title_svg
@@ -2062,7 +2200,9 @@ def get_big_rectangles(game):
 
 def get_footer_box(game):
     game_width = get_game_width(game)
-    footer_box_svg = '{}'.format(FOOTER_BOX.format(width=game_width))
+    text_pos = game_width - 255
+    footer_box_svg = '{}'.format(FOOTER_BOX.format(width=game_width,
+                                                   text_pos=text_pos))
 
     return footer_box_svg
 
@@ -2079,7 +2219,7 @@ def get_game_svg_str(game):
         add_home_pitcher_sub_division_lines(game),
         add_all_pitcher_box_scores(game),
         assemble_game_title_svg(game),
-        get_signature(game),
+        get_logo(game),
         get_box_score_totals(game),
         get_big_rectangles(game),
         get_footer_box(game),
