@@ -352,20 +352,6 @@ def process_at_bat(plate_appearance, event_list, game_obj, steal_description):
     pitcher_id = int(plate_appearance.get('pitcher'))
     inning_outs = int(plate_appearance.get('o'))
 
-    out_runner_supplemental_list = None
-    pitcher = None
-    for this_team in [game_obj.home_team, game_obj.away_team]:
-        if pitcher_id in this_team:
-            pitcher = this_team[pitcher_id]
-        elif steal_description:
-            out_runner_supplemental_list = (
-                PlateAppearance.get_out_runners_list(steal_description,
-                                                     this_team)
-            )
-
-    if not pitcher:
-        raise ValueError('Batter ID not in player_dict')
-
     batter_id = int(plate_appearance.get('batter'))
     if batter_id in game_obj.home_team:
         batter = game_obj.home_team[batter_id]
@@ -376,6 +362,23 @@ def process_at_bat(plate_appearance, event_list, game_obj, steal_description):
     else:
         raise ValueError('Batter ID not in player_dict')
 
+    out_runner_supplemental_list = None
+    pitcher = None
+    for this_team in [game_obj.home_team, game_obj.away_team]:
+        if pitcher_id in this_team:
+            pitcher = this_team[pitcher_id]
+        elif steal_description:
+            out_runner_supplemental_list = (
+                PlateAppearance.get_out_runners_list(steal_description,
+                                                     this_team,
+                                                     new_event_list,
+                                                     batter)
+            )
+
+    if not pitcher:
+        raise ValueError('Batter ID not in player_dict')
+
+
     start_datetime = get_datetime(plate_appearance.get('end_tfs_zulu'))
     end_datetime = get_datetime(plate_appearance.get('end_tfs_zulu'))
     plate_appearance_summary = plate_appearance.get('event').strip()
@@ -649,8 +652,9 @@ def process_half_inning(baseball_half_inning, inning_half_str, game_obj):
                 steal_description = event_description
         elif event_container.tag == 'atbat':
             if event_container.get('des'):
-                plate_appearance_obj = process_at_bat(event_container, event_list,
-                                                      game_obj, steal_description)
+                plate_appearance_obj = process_at_bat(
+                    event_container, event_list, game_obj, steal_description
+                )
 
                 plate_appearance_list.append(plate_appearance_obj)
                 event_list = []
@@ -679,12 +683,17 @@ def create_player(player_xml):
     else:
         player_num = None
 
-    return Player(player_xml.get('last'),
-                  player_xml.get('first'),
-                  int(player_xml.get('id')),
-                  None,
-                  None,
-                  player_num)
+    new_player = Player(player_xml.get('last'),
+                        player_xml.get('first'),
+                        int(player_xml.get('id')),
+                        None,
+                        None,
+                        player_num)
+
+    new_player.bat_side = player_xml.get('bats')
+    new_player.pitch_hand = player_xml.get('rl')
+
+    return new_player
 
 def init_player_list(player_obj, position):
     return [PlayerAppearance(player_obj, position, 1, 'top', 1)]
@@ -769,7 +778,8 @@ def process_team_xml(game_obj, team_xml):
         for player_xml in this_team_xml:
             if player_xml.tag == 'player':
                 player_id = int(player_xml.get('id'))
-
+                bat_side = player_xml.get('bats')
+                pitch_hand = player_xml.get('rl')
                 if player_id in this_team:
                     this_player = this_team[player_id]
 
@@ -781,6 +791,12 @@ def process_team_xml(game_obj, team_xml):
                     else:
                         this_player.number = ''
 
+                    if bat_side and not this_player.bat_side:
+                        this_player.bat_side = bat_side
+
+                    if pitch_hand and not this_player.pitch_hand:
+                        this_player.pitch_hand = pitch_hand
+
                     if (player_xml.get('era') is not None and
                             '-' not in player_xml.get('era')):
                         this_player.era = float(player_xml.get('era'))
@@ -805,6 +821,9 @@ def initialize_game_object(boxscore_xml):
     away_pitcher_status_dict = {}
     home_starting_pitcher_id = None
     away_starting_pitcher_id = None
+    temp = None
+    weather = None
+    attendance = None
 
     for item in boxscore_xml:
         if item.tag == 'batting':
@@ -841,8 +860,25 @@ def initialize_game_object(boxscore_xml):
                         )
                     else:
                         home_pitcher_status_dict[pitcher_id] = ''
+        elif item.tag == 'game_info':
+            match = search(
+                (r'.+<b>Weather</b>: (\d+) degrees, '
+                 r'([^\.]+)\.<br/><b>.+Att</b>: ([^\.]+)*\..+'),
+                item.text
+            )
+
+            if match:
+                temp = int(match.group(1))
+                weather = match.group(2)
+                attendance = int(match.group(3).replace(',', ''))
 
     game_obj = Game(home_team, away_team, game_venue, boxscore_date)
+    if temp:
+        game_obj.temp = temp
+    if weather:
+        game_obj.weather = weather
+    if attendance:
+        game_obj.attendance = attendance
 
     return (game_obj,
             away_pitcher_status_dict,
