@@ -3,7 +3,7 @@ from collections import namedtuple
 from baseball.baseball_events import Pickoff, RunnerAdvance, Pitch
 
 
-NOT_AT_BAT_CODE_LIST = ['SB', 'SF', 'BB', 'CI', 'FI', 'IBB', 'HBP', 'CS', 'PO']
+NOT_AT_BAT_CODE_LIST = ['SH', 'SF', 'BB', 'CI', 'FI', 'IBB', 'HBP', 'CS', 'PO']
 HIT_CODE_LIST = ['1B', '2B', '3B', 'HR']
 
 InningStatsTuple = namedtuple('InningStatsTuple', 'S P BB K LOB E H R')
@@ -44,6 +44,9 @@ def process_pickoffs(plate_appearance, first_base, second_base, third_base):
 
 def process_baserunners(plate_appearance, last_plate_appearance,
                         first_base, second_base, third_base):
+    first_base_list = [first_base] if first_base else []
+    second_base_list = [second_base] if second_base else []
+    third_base_list = [third_base] if third_base else []
     for event in plate_appearance.event_list:
         if isinstance(event, RunnerAdvance):
             if (plate_appearance == last_plate_appearance and
@@ -51,32 +54,39 @@ def process_baserunners(plate_appearance, last_plate_appearance,
                 break
             else:
                 if event.end_base == '1B':
-                    first_base = event.runner
+                    first_base_list.append(event.runner)
                 elif event.end_base == '2B':
-                    second_base = event.runner
-
-                    if (event.start_base == '1B' and
-                            first_base == event.runner):
-                        first_base = None
+                    second_base_list.append(event.runner)
+                    if event.runner in first_base_list:
+                        first_base_list.remove(event.runner)
                 elif event.end_base == '3B':
-                    third_base = event.runner
-
-                    if (event.start_base == '1B' and
-                            first_base == event.runner):
-                        first_base = None
-                    elif (event.start_base == '2B' and
-                          second_base == event.runner):
-                        second_base = None
+                    third_base_list.append(event.runner)
+                    if event.runner in first_base_list:
+                        first_base_list.remove(event.runner)
+                    if event.runner in second_base_list:
+                        second_base_list.remove(event.runner)
                 elif event.end_base == '' or 'score':
-                    if (event.start_base == '1B' and
-                            first_base == event.runner):
-                        first_base = None
-                    elif (event.start_base == '2B' and
-                          second_base == event.runner):
-                        second_base = None
-                    elif (event.start_base == '3B' and
-                          third_base == event.runner):
-                        third_base = None
+                    if event.runner in first_base_list:
+                        first_base_list.remove(event.runner)
+                    if event.runner in second_base_list:
+                        second_base_list.remove(event.runner)
+                    if event.runner in third_base_list:
+                        third_base_list.remove(event.runner)
+
+    if first_base_list:
+        first_base = first_base_list[0]
+    else:
+        first_base = None
+
+    if second_base_list:
+        second_base = second_base_list[0]
+    else:
+        second_base = None
+
+    if third_base_list:
+        third_base = third_base_list[0]
+    else:
+        third_base = None
 
     return first_base, second_base, third_base
 
@@ -594,6 +604,8 @@ def get_pitcher_strikes(pitcher, inning_half_list):
                 for event in plate_appearance.event_list:
                     if (isinstance(event, Pitch) and
                             event.pitch_description != 'Ball' and
+                            event.pitch_description != 'Intent Ball' and
+                            event.pitch_description != 'Automatic Ball' and
                             event.pitch_description != 'Ball In Dirt' and
                             event.pitch_description != 'Hit By Pitch'):
                         num_strikes += 1
@@ -607,7 +619,8 @@ def get_pitcher_pitches(pitcher, inning_half_list):
         for plate_appearance in inning_half:
             if pitcher == plate_appearance.pitcher:
                 for event in plate_appearance.event_list:
-                    if isinstance(event, Pitch):
+                    if (isinstance(event, Pitch) and
+                            event.pitch_description != 'Automatic Ball'):
                         num_pitches += 1
 
     return num_pitches
@@ -670,6 +683,8 @@ def get_strikes(appearance_list):
         for event in plate_appearance.event_list:
             if (isinstance(event, Pitch) and
                     event.pitch_description != 'Ball' and
+                    event.pitch_description != 'Intent Ball' and
+                    event.pitch_description != 'Automatic Ball' and
                     event.pitch_description != 'Ball In Dirt' and
                     event.pitch_description != 'Hit By Pitch'):
                 num_strikes += 1
@@ -781,19 +796,30 @@ def count_summaries_by_keyword(inning_half_list, keyword):
     return num_keyword_appearances
 
 def count_runner_advance_unique_keywords(inning_half_list, keyword):
-    after_pitch = False
     num_keyword_appearances = 0
 
     for appearance_list in inning_half_list:
         for appearance in appearance_list:
+            runner_list = []
+            previous_run_description = None
+            new_event_next = True
             for event in appearance.event_list:
-                if isinstance(event, Pitch):
-                    after_pitch = True
-                elif isinstance(event, RunnerAdvance):
-                    if after_pitch and keyword in event.run_description:
+                if isinstance(event, RunnerAdvance):
+                    if event.run_description != previous_run_description:
+                        runner_list = [event.runner]
+                        new_event_next = True
+                    elif (event.run_description == previous_run_description and
+                          event.runner in runner_list):
+                        runner_list = [event.runner]
+                        new_event_next = True
+                    else:
+                        runner_list.append(event.runner)
+                        new_event_next = False
+
+                    if new_event_next and keyword in event.run_description:
                         num_keyword_appearances += 1
 
-                    after_pitch = False
+                    previous_run_description = event.run_description
 
     return num_keyword_appearances
 
